{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "FragGeneScan: find (fragmented) genes in short reads",
            "doc": "FragGeneScan is an application for finding (fragmented) genes in short\nreads. It can also be applied to predict prokaryotic genes in incomplete\nassemblies or complete genomes.\n\nFragGeneScan was first released through omics website (http://omics.informatics.indiana.edu/FragGeneScan/)\nin March 2010, where you can find its old releases. FragGeneScan migrated to SourceForge in October, 2013\n(https://sourceforge.net/projects/fraggenescan/).\n\nVersion 1.20 can be downloaded here:\nhttps://sourceforge.net/projects/fraggenescan/files/\n",
            "baseCommand": [],
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "label": "name of built in models",
                            "name": "#FragGeneScan1_20-types.yaml/model",
                            "symbols": [
                                "#FragGeneScan1_20-types.yaml/model/complete",
                                "#FragGeneScan1_20-types.yaml/model/sanger_5",
                                "#FragGeneScan1_20-types.yaml/model/sanger_10",
                                "#FragGeneScan1_20-types.yaml/model/454_5",
                                "#FragGeneScan1_20-types.yaml/model/454_10",
                                "#FragGeneScan1_20-types.yaml/model/454_30",
                                "#FragGeneScan1_20-types.yaml/model/illumina_5",
                                "#FragGeneScan1_20-types.yaml/model/illumina_10"
                            ]
                        }
                    ],
                    "id": "#FragGeneScan1_20-types.yaml"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011929"
                            ],
                            "version": [
                                "1.20"
                            ],
                            "package": "fraggenescan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "arguments": [
                "mkdir",
                "train",
                ";",
                "ln",
                "-s",
                "$(inputs.model.path)",
                "train/",
                ";",
                "ln",
                "-s",
                "$(inputs.prob_forward.path)",
                "train/gene",
                ";",
                "ln",
                "-s",
                "$(inputs.prob_backward.path)",
                "train/rgene",
                ";",
                "ln",
                "-s",
                "$(inputs.prob_noncoding.path)",
                "train/noncoding",
                ";",
                "ln",
                "-s",
                "$(inputs.prob_start.path)",
                "train/start",
                ";",
                "ln",
                "-s",
                "$(inputs.prob_stop.path)",
                "train/stop",
                ";",
                "ln",
                "-s",
                "$(inputs.prob_start1.path)",
                "train/start1",
                ";",
                "ln",
                "-s",
                "$(inputs.prob_stop1.path)",
                "train/stop1",
                ";",
                "ln",
                "-s",
                "$(inputs.pwm_dist.path)",
                "train/pwm",
                ";",
                "FragGeneScan",
                "-o",
                "$(runtime.outdir)/predicted_cds"
            ],
            "inputs": [
                {
                    "doc": "True if the sequence file has complete genomic sequences\nFalse if the sequence file has short sequence reads\n",
                    "type": "boolean",
                    "inputBinding": {
                        "valueFrom": "${ if (self) {\n     return [ \"-w\", \"1\" ];\n   } else {\n     return [ \"-w\", \"0\" ];\n   }\n }\n"
                    },
                    "id": "#FragGeneScan1_20.cwl/completeSeq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-t",
                        "valueFrom": "$(self.basename)"
                    },
                    "id": "#FragGeneScan1_20.cwl/model"
                },
                {
                    "type": "File",
                    "label": "Backward probability model",
                    "id": "#FragGeneScan1_20.cwl/prob_backward"
                },
                {
                    "type": "File",
                    "label": "Forward probability model",
                    "id": "#FragGeneScan1_20.cwl/prob_forward"
                },
                {
                    "type": "File",
                    "label": "Noncoding probability model",
                    "id": "#FragGeneScan1_20.cwl/prob_noncoding"
                },
                {
                    "type": "File",
                    "label": "Start probability model",
                    "id": "#FragGeneScan1_20.cwl/prob_start"
                },
                {
                    "type": "File",
                    "label": "Start1 probability model",
                    "id": "#FragGeneScan1_20.cwl/prob_start1"
                },
                {
                    "type": "File",
                    "label": "Stop probability model",
                    "id": "#FragGeneScan1_20.cwl/prob_stop"
                },
                {
                    "type": "File",
                    "label": "Stop1 probability model",
                    "id": "#FragGeneScan1_20.cwl/prob_stop1"
                },
                {
                    "type": "File",
                    "label": "pwm distribution",
                    "id": "#FragGeneScan1_20.cwl/pwm_dist"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#FragGeneScan1_20.cwl/sequence"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "id": "#FragGeneScan1_20.cwl/threadNumber"
                }
            ],
            "id": "#FragGeneScan1_20.cwl",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "predicted_cds.faa"
                    },
                    "id": "#FragGeneScan1_20.cwl/predictedCDS"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "InterProScan: protein sequence classifier",
            "doc": "Version 5.21-60 can be downloaded here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToDownload\n\nDocumentation on how to run InterProScan 5 can be found here:\nhttps://github.com/ebi-pf-team/interproscan/wiki/HowToRun\n",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#InterProScan-apps.yaml/apps",
                            "symbols": [
                                "#InterProScan-apps.yaml/apps/TIGRFAM",
                                "#InterProScan-apps.yaml/apps/SFLD",
                                "#InterProScan-apps.yaml/apps/SUPERFAMILY",
                                "#InterProScan-apps.yaml/apps/Gene3D",
                                "#InterProScan-apps.yaml/apps/Hamap",
                                "#InterProScan-apps.yaml/apps/Coils",
                                "#InterProScan-apps.yaml/apps/ProSiteProfiles",
                                "#InterProScan-apps.yaml/apps/SMART",
                                "#InterProScan-apps.yaml/apps/CDD",
                                "#InterProScan-apps.yaml/apps/PRINTS",
                                "#InterProScan-apps.yaml/apps/PIRSF",
                                "#InterProScan-apps.yaml/apps/ProSitePatterns",
                                "#InterProScan-apps.yaml/apps/Pfam",
                                "#InterProScan-apps.yaml/apps/ProDom",
                                "#InterProScan-apps.yaml/apps/MobiDBLite"
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#InterProScan-protein_formats.yaml/protein_formats",
                            "symbols": [
                                "#InterProScan-protein_formats.yaml/protein_formats/TSV",
                                "#InterProScan-protein_formats.yaml/protein_formats/XML",
                                "#InterProScan-protein_formats.yaml/protein_formats/GFF3"
                            ]
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005829"
                            ],
                            "version": [
                                "5.21-60"
                            ],
                            "package": "interproscan"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#InterProScan-apps.yaml/apps"
                        }
                    ],
                    "inputBinding": {
                        "itemSeparator": ",",
                        "prefix": "--applications"
                    },
                    "id": "#InterProScan5.21-60.cwl/applications"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#InterProScan5.21-60.cwl/proteinFile"
                }
            ],
            "baseCommand": "interproscan.sh",
            "arguments": [
                {
                    "valueFrom": "i5_annotations",
                    "prefix": "--outfile"
                },
                {
                    "valueFrom": "TSV",
                    "prefix": "--formats"
                },
                "--disable-precalc",
                "--goterms",
                "--pathways"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "i5_annotations"
                    },
                    "id": "#InterProScan5.21-60.cwl/i5Annotations"
                }
            ],
            "id": "#InterProScan5.21-60.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#collate_unique_SSU_headers.cwl/hits"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sorted_uniq_names",
                    "id": "#collate_unique_SSU_headers.cwl/unique_hits"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/hits",
                            "id": "#collate_unique_SSU_headers.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "scatter": "#collate_unique_SSU_headers.cwl/extract_coord_lines/summary",
                    "out": [
                        "#collate_unique_SSU_headers.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n",
                                "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1}"
                        ],
                        "stdout": "names",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#collate_unique_SSU_headers.cwl/extract_names/extract_names/names",
                                "outputBinding": {
                                    "glob": "names"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/extract_coord_lines/coord_lines",
                            "id": "#collate_unique_SSU_headers.cwl/extract_names/coordinate_lines"
                        }
                    ],
                    "scatter": "#collate_unique_SSU_headers.cwl/extract_names/coordinate_lines",
                    "out": [
                        "#collate_unique_SSU_headers.cwl/extract_names/names"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/extract_names"
                },
                {
                    "run": {
                        "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "inputBinding": {
                                    "position": 1
                                },
                                "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names/names"
                            }
                        ],
                        "baseCommand": [
                            "sort",
                            "--unique"
                        ],
                        "stdout": "sorted_uniq_names",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/sort_uniq_names/sorted_uniq_names",
                                "outputBinding": {
                                    "glob": "sorted_uniq_names"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#collate_unique_SSU_headers.cwl/extract_names/names",
                            "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names/names"
                        }
                    ],
                    "out": [
                        "#collate_unique_SSU_headers.cwl/sort_uniq_names/sorted_uniq_names"
                    ],
                    "id": "#collate_unique_SSU_headers.cwl/sort_uniq_names"
                }
            ],
            "id": "#collate_unique_SSU_headers.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "index a sequence file for use by esl-sfetch",
            "doc": "https://github.com/EddyRivasLab/easel",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 10,
                        "valueFrom": "$(self.basename)"
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-index.cwl/sequences"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "cp",
                "$(inputs.sequences.path)",
                "$(runtime.outdir)",
                {
                    "valueFrom": ";",
                    "shellQuote": false
                },
                "esl-sfetch",
                "--index"
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "$(inputs.sequences.format)",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#esl-sfetch-index.cwl/sequences_with_index"
                }
            ],
            "id": "#esl-sfetch-index.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "extract by names from an indexed sequence file",
            "doc": "https://github.com/EddyRivasLab/easel",
            "inputs": [
                {
                    "label": "sequence file indexed by esl-sfetch-index",
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 1
                    },
                    "format": [
                        "http://edamontology.org/format_1929",
                        "http://edamontology.org/format_1927",
                        "http://edamontology.org/format_1936",
                        "http://edamontology.org/format_1961",
                        "http://edamontology.org/format_1963"
                    ],
                    "id": "#esl-sfetch-manyseqs.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "label": "sequence names to retrieve, one per line",
                    "streamable": true,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names"
                },
                {
                    "doc": "GDF format: <newname> <from> <to> <source seqname>\nspace/tabdelimited\n",
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "id": "#esl-sfetch-manyseqs.cwl/names_contain_subseq_coords"
                }
            ],
            "baseCommand": [
                "esl-sfetch"
            ],
            "stdout": "sequences",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#esl-sfetch-manyseqs.cwl/sequences",
                    "outputBinding": {
                        "glob": "sequences"
                    }
                }
            ],
            "id": "#esl-sfetch-manyseqs.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "streamable": true,
                    "id": "#extract_coord_lines.cwl/summary"
                }
            ],
            "baseCommand": [
                "grep",
                "-v",
                "^#"
            ],
            "stdout": "coord_lines",
            "outputs": [
                {
                    "type": "File",
                    "id": "#extract_coord_lines.cwl/coord_lines",
                    "outputBinding": {
                        "glob": "coord_lines"
                    }
                }
            ],
            "id": "#extract_coord_lines.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005534"
                            ],
                            "version": [
                                "0.0.13"
                            ],
                            "package": "fastx_toolkit"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "format": "http://edamontology.org/format_1930",
                    "id": "#fastq_to_fasta.cwl/fastq"
                }
            ],
            "baseCommand": [
                "fastq_to_fasta"
            ],
            "stdout": "fasta",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#fastq_to_fasta.cwl/fasta",
                    "outputBinding": {
                        "glob": "fasta"
                    }
                }
            ],
            "id": "#fastq_to_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "label": "report sequences <= this E-value threshold in output",
                    "inputBinding": {
                        "prefix": "-E"
                    },
                    "id": "#hmmsearch.cwl/e_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#hmmsearch.cwl/hmm_profiles"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#hmmsearch.cwl/sequence_query"
                }
            ],
            "baseCommand": [
                "hmmersearch"
            ],
            "arguments": [
                "--domtblout",
                "per_domain_summary.txt",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "per_domain_summary.txt"
                    },
                    "id": "#hmmsearch.cwl/per_domain_summary"
                }
            ],
            "id": "#hmmsearch.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/16s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/23s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/5s_rRNA_hmmer_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/sequences"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/tRNA_matches"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/unique_rRNA_hits"
                },
                {
                    "type": "File",
                    "id": "#mask_RNA.cwl/unique_tRNA_hits"
                }
            ],
            "baseCommand": [],
            "arguments": [
                "ln",
                "-s",
                "$(inputs.unique_rRNA_hits.path)",
                "nhmmer.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.16s_rRNA_hmmer_matches.path)",
                "nhmmer.16s.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.23s_rRNA_hmmer_matches.path)",
                "nhmmer.23s.txt",
                ";",
                "ln",
                "-s",
                "$(inputs.5s_rRNA_hmmer_matches.path)",
                "nhmmer.5s.txt",
                ";",
                "rnaMaskingStep.py",
                "--hmmer",
                "hmmer.txt",
                "--nhmmer",
                "$(inputs.unique_tRNA_hits.path)",
                "--seq_id",
                "$(inputs.tRNA_matches.path)",
                "--input",
                "$(inputs.sequences.path)",
                "--output",
                "masked_sequences.fasta"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputBinding": {
                        "glob": "masked_sequences.fasta"
                    },
                    "id": "#mask_RNA.cwl/masked_sequences"
                }
            ],
            "id": "#mask_RNA.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "search profile(s) against a sequence database",
            "hints": [
                {
                    "class": "SoftwareRequirement",
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_005305"
                            ],
                            "version": [
                                "3.1b2"
                            ],
                            "package": "hmmer"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "report sequences >= this bit score threshold in output",
                    "inputBinding": {
                        "prefix": "-T"
                    },
                    "id": "#nhmmer.cwl/bitscore_threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "format": "http://edamontology.org/format_1370",
                    "id": "#nhmmer.cwl/query"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#nhmmer.cwl/sequences"
                }
            ],
            "baseCommand": [
                "nhmmer"
            ],
            "arguments": [
                "--tblout",
                "per_target_summary.txt",
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "--cpu"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "per_target_summary.txt"
                    },
                    "id": "#nhmmer.cwl/per_target_summary"
                }
            ],
            "id": "#nhmmer.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#rRNA_selection.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "rRNA protein model to search with",
                    "id": "#rRNA_selection.cwl/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#rRNA_selection.cwl/hmmsearch/per_domain_summary",
                    "id": "#rRNA_selection.cwl/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#rRNA_selection.cwl/fetch_aligned_sequences/sequences",
                    "id": "#rRNA_selection.cwl/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/hmmsearch/per_domain_summary",
                            "id": "#rRNA_selection.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#rRNA_selection.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(18) from (ali coord): The start of the MEA alignment of this\n     domain with respect to the sequence, numbered 1..L for a\n     sequence of L residues.\n(19) to (ali coord): The end of the MEA alignment of this domain\n     with respect to the sequence, numbered 1..L for a sequence of\n     L residues.\n",
                                "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1, $18, $19, $1}"
                        ],
                        "stdout": "formatted_names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#rRNA_selection.cwl/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "formatted_names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/extract_coord_lines/coord_lines",
                            "id": "#rRNA_selection.cwl/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#rRNA_selection.cwl/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#rRNA_selection.cwl/indexed_sequences",
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#rRNA_selection.cwl/extract_coordinates/formatted_names_and_coords",
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#rRNA_selection.cwl/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#rRNA_selection.cwl/fetch_aligned_sequences"
                },
                {
                    "run": "#hmmsearch.cwl",
                    "in": [
                        {
                            "default": "1.0E-5",
                            "id": "#rRNA_selection.cwl/hmmsearch/e_threshold"
                        },
                        {
                            "source": "#rRNA_selection.cwl/model",
                            "id": "#rRNA_selection.cwl/hmmsearch/hmm_profiles"
                        },
                        {
                            "source": "#rRNA_selection.cwl/indexed_sequences",
                            "id": "#rRNA_selection.cwl/hmmsearch/sequence_query"
                        }
                    ],
                    "out": [
                        "#rRNA_selection.cwl/hmmsearch/per_domain_summary"
                    ],
                    "id": "#rRNA_selection.cwl/hmmsearch"
                }
            ],
            "id": "#rRNA_selection.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": null,
                            "package": "gunzip"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#seqprep-merge.cwl/forward_unmerged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#seqprep-merge.cwl/merged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#seqprep-merge.cwl/reverse_unmerged_reads"
                }
            ],
            "baseCommand": [
                "gunzip",
                "-c"
            ],
            "stdout": "merged_with_unmerged_reads",
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#seqprep-merge.cwl/merged_with_unmerged_reads",
                    "outputBinding": {
                        "glob": "merged_with_unmerged_reads"
                    }
                }
            ],
            "id": "#seqprep-merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_013004"
                            ],
                            "version": [
                                "1.1"
                            ],
                            "package": "seqprep"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "first read input fastq",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "id": "#seqprep.cwl/forward_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "label": "second read input fastq",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "id": "#seqprep.cwl/reverse_reads"
                }
            ],
            "baseCommand": "SeqPrep",
            "arguments": [
                "-1",
                "forward_unmerged.fastq.gz",
                "-2",
                "reverse_unmerged.fastq.gz",
                "-s",
                "merged.fastq.gz"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "forward_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/forward_unmerged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "merged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/merged_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "reverse_unmerged.fastq.gz"
                    },
                    "id": "#seqprep.cwl/reverse_unmerged_reads"
                }
            ],
            "id": "#seqprep.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".ssi",
                    "format": "http://edamontology.org/format_1929",
                    "id": "#tRNA_selection.cwl/indexed_sequences"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "label": "tRNA model to search with",
                    "id": "#tRNA_selection.cwl/model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#tRNA_selection.cwl/nhmmer/per_target_summary",
                    "id": "#tRNA_selection.cwl/hmmer_search_results"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "outputSource": "#tRNA_selection.cwl/fetch_aligned_sequences/sequences",
                    "id": "#tRNA_selection.cwl/matching_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#extract_coord_lines.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/nhmmer/per_target_summary",
                            "id": "#tRNA_selection.cwl/extract_coord_lines/summary"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/extract_coord_lines/coord_lines"
                    ],
                    "id": "#tRNA_selection.cwl/extract_coord_lines"
                },
                {
                    "run": {
                        "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates",
                        "class": "CommandLineTool",
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "position": 1
                                },
                                "streamable": true,
                                "doc": "The required columns are as follows:\n(1) target name: The name of the target sequence or profile.\n(7) alifrom: The position in the target sequence at which the hit\n             starts\n(8) ali to: The position in the target sequence at which the hit\n            ends.\n",
                                "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates/coordinate_lines"
                            }
                        ],
                        "baseCommand": [
                            "awk",
                            "{print $1, $7, $8, $1}"
                        ],
                        "stdout": "formatted_names_and_coords",
                        "outputs": [
                            {
                                "type": "File",
                                "id": "#tRNA_selection.cwl/extract_coordinates/extract_coordinates/formatted_names_and_coords",
                                "outputBinding": {
                                    "glob": "formatted_names_and_coords"
                                }
                            }
                        ]
                    },
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/extract_coord_lines/coord_lines",
                            "id": "#tRNA_selection.cwl/extract_coordinates/coordinate_lines"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/extract_coordinates/formatted_names_and_coords"
                    ],
                    "id": "#tRNA_selection.cwl/extract_coordinates"
                },
                {
                    "run": "#esl-sfetch-manyseqs.cwl",
                    "in": [
                        {
                            "source": "#tRNA_selection.cwl/indexed_sequences",
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/indexed_sequences"
                        },
                        {
                            "source": "#tRNA_selection.cwl/extract_coordinates/formatted_names_and_coords",
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/names"
                        },
                        {
                            "default": true,
                            "id": "#tRNA_selection.cwl/fetch_aligned_sequences/names_contain_subseq_coords"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/fetch_aligned_sequences/sequences"
                    ],
                    "id": "#tRNA_selection.cwl/fetch_aligned_sequences"
                },
                {
                    "run": "#nhmmer.cwl",
                    "in": [
                        {
                            "default": 40,
                            "id": "#tRNA_selection.cwl/nhmmer/bitscore_threshold"
                        },
                        {
                            "source": "#tRNA_selection.cwl/model",
                            "id": "#tRNA_selection.cwl/nhmmer/query"
                        },
                        {
                            "source": "#tRNA_selection.cwl/indexed_sequences",
                            "id": "#tRNA_selection.cwl/nhmmer/sequences"
                        }
                    ],
                    "out": [
                        "#tRNA_selection.cwl/nhmmer/per_target_summary"
                    ],
                    "id": "#tRNA_selection.cwl/nhmmer"
                }
            ],
            "id": "#tRNA_selection.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_011848"
                            ],
                            "version": [
                                "0.32",
                                "0.35",
                                "0.36"
                            ],
                            "package": "trimmomatic"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "types": [
                        {
                            "type": "enum",
                            "name": "#trimmomatic-end_mode.yaml/end_mode",
                            "symbols": [
                                "#trimmomatic-end_mode.yaml/end_mode/SE",
                                "#trimmomatic-end_mode.yaml/end_mode/PE"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-sliding_window.yaml/slidingWindow",
                            "fields": [
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/windowSize",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-sliding_window.yaml/slidingWindow/requiredQuality",
                                    "type": "int"
                                }
                            ]
                        },
                        {
                            "type": "enum",
                            "name": "#trimmomatic-phred.yaml/phred",
                            "symbols": [
                                "#trimmomatic-phred.yaml/phred/64",
                                "#trimmomatic-phred.yaml/phred/33"
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping",
                            "fields": [
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/adapters",
                                    "type": "File",
                                    "doc": "FASTA file containing adapters, PCR sequences, etc. It is used to search\nfor and remove these sequences in the input FASTQ file(s)\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/seedMismatches",
                                    "type": "int",
                                    "doc": "specifies the maximum mismatch count which will still allow a full match\nto be performed\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/palindromeClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between the two 'adapter ligated' reads\nmust be for PE palindrome read alignment.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/simpleClipThreshold",
                                    "type": "int",
                                    "doc": "specifies how accurate the match between any adapter etc. sequence must\nbe against a read\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/minAdapterLength",
                                    "type": [
                                        "null",
                                        "int"
                                    ],
                                    "doc": "In addition to the alignment score, palindrome mode can verify that a\nminimum length of adapter has been detected. If unspecified, this\ndefaults to 8 bases, for historical reasons. However, since palindrome\nmode has a very low false positive rate, this can be safely reduced, even\ndown to 1, to allow shorter adapter fragments to be removed.\n"
                                },
                                {
                                    "name": "#trimmomatic-illumina_clipping.yaml/illuminaClipping/keepBothReads",
                                    "type": "boolean",
                                    "doc": "After read-though has been detected by palindrome mode, and the adapter\nsequence removed, the reverse read contains the same sequence information\nas the forward read, albeit in reverse complement. For this reason, the\ndefault behaviour is to entirely drop the reverse read. By specifying\n\"true\" for this parameter, the reverse read will also be retained, which\nmay be useful e.g. if the downstream tools cannot handle a combination of\npaired and unpaired reads.  \n"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimmomatic-max_info.yaml/maxinfo",
                            "fields": [
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/targetLength",
                                    "type": "int"
                                },
                                {
                                    "name": "#trimmomatic-max_info.yaml/maxinfo/strictness",
                                    "type": "int"
                                }
                            ]
                        }
                    ],
                    "class": "SchemaDefRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 101,
                        "prefix": "AVGQUAL:",
                        "separate": false
                    },
                    "doc": "Drop the read if the average quality is below the specified level\n",
                    "id": "#trimmomatic.cwl/avgqual"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "CROP:",
                        "separate": false
                    },
                    "doc": "Removes bases regardless of quality from the end of the read, so that the\nread has maximally the specified length after this step has been\nperformed. Steps performed after CROP might of course further shorten the\nread. The value is the number of bases to keep, from the start of the read.\n",
                    "id": "#trimmomatic.cwl/crop"
                },
                {
                    "type": "#trimmomatic-end_mode.yaml/end_mode",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Single End (SE) or Paired End (PE) mode\n",
                    "id": "#trimmomatic.cwl/end_mode"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 13,
                        "prefix": "HEADCROP:",
                        "separate": false
                    },
                    "doc": "Removes the specified number of bases, regardless of quality, from the\nbeginning of the read.\nThe numbser specified is the number of bases to keep, from the start of\nthe read.\n",
                    "id": "#trimmomatic.cwl/headcrop"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-illumina_clipping.yaml/illuminaClipping"
                    ],
                    "inputBinding": {
                        "valueFrom": "ILLUMINACLIP:$(self.adapters_file.path):$(self.seedMismatches):$(self.palindromeClipThreshold):$(self.simpleClipThreshold):$(self.minAdapterLength):$(self.keepBothReads)\n",
                        "position": 11
                    },
                    "doc": "Cut adapter and other illumina-specific sequences from the read.",
                    "id": "#trimmomatic.cwl/illuminaClip"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "doc": "JVM arguments should be a quoted, space separated list\n(e.g. \"-Xms128m -Xmx512m\")\n",
                    "id": "#trimmomatic.cwl/java_opts"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "LEADING:",
                        "separate": false
                    },
                    "doc": "Remove low quality bases from the beginning. As long as a base has a\nvalue below this threshold the base is removed and the next base will be\ninvestigated.\n",
                    "id": "#trimmomatic.cwl/leading"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-max_info.yaml/maxinfo"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "MAXINFO:$(self.targetLength):$(strictness)\n"
                    },
                    "doc": "Performs an adaptive quality trim, balancing the benefits of retaining\nlonger reads against the costs of retaining bases with errors.\n<targetLength>: This specifies the read length which is likely to allow\nthe location of the read within the target sequence to be determined.\n<strictness>: This value, which should be set between 0 and 1, specifies\nthe balance between preserving as much read length as possible vs.\nremoval of incorrect bases. A low value of this parameter (<0.2) favours\nlonger reads, while a high value (>0.8) favours read correctness.\n",
                    "id": "#trimmomatic.cwl/maxinfo"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 100,
                        "prefix": "MINLEN:",
                        "separate": false
                    },
                    "doc": "This module removes reads that fall below the specified minimal length.\nIf required, it should normally be after all other processing steps.\nReads removed by this step will be counted and included in the \"dropped\nreads\" count presented in the trimmomatic summary.\n",
                    "id": "#trimmomatic.cwl/minlen"
                },
                {
                    "type": "int",
                    "default": 1,
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-threads"
                    },
                    "doc": "Number of threads",
                    "id": "#trimmomatic.cwl/nthreads"
                },
                {
                    "type": "#trimmomatic-phred.yaml/phred",
                    "default": "64",
                    "inputBinding": {
                        "prefix": "-phred",
                        "separate": false,
                        "position": 4
                    },
                    "doc": "\"33\" or \"64\" specifies the base quality encoding. Default: 64\n",
                    "id": "#trimmomatic.cwl/phred"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "FASTQ file of reads (R1 reads in Paired End mode)",
                    "id": "#trimmomatic.cwl/reads1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "FASTQ file of R2 reads in Paired End mode",
                    "id": "#trimmomatic.cwl/reads2"
                },
                {
                    "type": [
                        "null",
                        "#trimmomatic-sliding_window.yaml/slidingWindow"
                    ],
                    "inputBinding": {
                        "position": 15,
                        "valueFrom": "SLIDINGWINDOW:$(self.windowSize):$(self.requiredQuality)\n"
                    },
                    "doc": "Perform a sliding window trimming, cutting once the average quality\nwithin the window falls below a threshold. By considering multiple\nbases, a single poor quality base will not cause the removal of high\nquality data later in the read.\n<windowSize> specifies the number of bases to average across\n<requiredQuality> specifies the average quality required\n",
                    "id": "#trimmomatic.cwl/slidingwindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED33",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 33.",
                    "id": "#trimmomatic.cwl/tophred33"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "TOPHRED64",
                        "separate": false
                    },
                    "doc": "This (re)encodes the quality part of the FASTQ file to base 64.",
                    "id": "#trimmomatic.cwl/tophred64"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 14,
                        "prefix": "TRAILING:",
                        "separate": false
                    },
                    "doc": "Remove low quality bases from the end. As long as a base has a value\nbelow this threshold the base is removed and the next base (which as\ntrimmomatic is starting from the 3' prime end would be base preceding\nthe just removed base) will be investigated. This approach can be used\nremoving the special Illumina \"low quality segment\" regions (which are\nmarked with quality score of 2), but we recommend Sliding Window or\nMaxInfo instead\n",
                    "id": "#trimmomatic.cwl/trailing"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trim.log"
                    },
                    "label": "Trimmomatic log",
                    "doc": "log of all read trimmings, indicating the following details:\n  the read name\n  the surviving sequence length\n  the location of the first surviving base, aka. the amount trimmed from the start\n  the location of the last surviving base in the original read\n  the amount trimmed from the end\n",
                    "id": "#trimmomatic.cwl/output_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).trimmed.fastq"
                    },
                    "id": "#trimmomatic.cwl/reads1_trimmed"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "$(inputs.reads1.nameroot).unpaired.trimmed.fastq"
                    },
                    "id": "#trimmomatic.cwl/reads1_trimmed_unpaired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#trimmomatic.cwl/reads2_trimmed_paired"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "outputBinding": {
                        "glob": "${ if (inputs.reads2 ) {\n     return inputs.reads2.nameroot + '.unpaired.trimmed.fastq';\n   } else {\n     return null;\n   }\n }\n"
                    },
                    "id": "#trimmomatic.cwl/reads2_trimmed_unpaired"
                }
            ],
            "baseCommand": [
                "java",
                "org.usadellab.trimmomatic.Trimmomatic"
            ],
            "arguments": [
                {
                    "valueFrom": "trim.log",
                    "prefix": "-trimlog",
                    "position": 4
                },
                {
                    "valueFrom": "$(inputs.reads1.nameroot).trimmed.fastq",
                    "position": 7
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads1.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 8
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 9
                },
                {
                    "valueFrom": "${\n  if (inputs.end_mode == \"PE\" && inputs.reads2) {\n    return inputs.reads2.nameroot + '.trimmed.unpaired.fastq';\n  } else {\n    return null;\n  }\n}\n",
                    "position": 10
                }
            ],
            "doc": "Trimmomatic is a fast, multithreaded command line tool that can be used to trim and crop\nIllumina (FASTQ) data as well as to remove adapters. These adapters can pose a real problem\ndepending on the library preparation and downstream application.\nThere are two major modes of the program: Paired end mode and Single end mode. The\npaired end mode will maintain correspondence of read pairs and also use the additional\ninformation contained in paired reads to better find adapter or PCR primer fragments\nintroduced by the library preparation process.\nTrimmomatic works with FASTQ files (using phred + 33 or phred + 64 quality scores,\ndepending on the Illumina pipeline used).\n",
            "id": "#trimmomatic.cwl"
        },
        {
            "class": "Workflow",
            "label": "EMG pipeline v3.0 (draft CWL version)",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#InterProScan-apps.yaml/apps"
                        },
                        {
                            "$import": "#InterProScan-protein_formats.yaml/protein_formats"
                        },
                        {
                            "$import": "#trimmomatic-sliding_window.yaml/slidingWindow"
                        },
                        {
                            "$import": "#trimmomatic-end_mode.yaml/end_mode"
                        },
                        {
                            "$import": "#trimmomatic-phred.yaml/phred"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/16S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/23S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/5S_model"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/forward_reads"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_model"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_prob_backward"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_prob_forward"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_prob_noncoding"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_prob_start"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_prob_start1"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_prob_stop"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_prob_stop1"
                },
                {
                    "type": "File",
                    "id": "#main/fraggenescan_pwm_dist"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1930",
                    "id": "#main/reverse_reads"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1370",
                    "id": "#main/tRNA_model"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/interproscan/i5Annotations",
                    "id": "#main/annotations"
                },
                {
                    "type": "File",
                    "outputSource": "#main/fraggenescan/predictedCDS",
                    "id": "#main/pCDS"
                },
                {
                    "type": "File",
                    "outputSource": "#main/mask_rRNA_and_tRNA/masked_sequences",
                    "id": "#main/processed_sequences"
                }
            ],
            "steps": [
                {
                    "run": "#collate_unique_SSU_headers.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/find_16S_matches/hmmer_search_results",
                                "#main/find_23S_matches/hmmer_search_results",
                                "#main/find_5S_matches/hmmer_search_results"
                            ],
                            "id": "#main/collate_unique_rRNA_hmmer_hits/hits"
                        }
                    ],
                    "out": [
                        "#main/collate_unique_rRNA_hmmer_hits/unique_hits"
                    ],
                    "id": "#main/collate_unique_rRNA_hmmer_hits"
                },
                {
                    "run": "#collate_unique_SSU_headers.cwl",
                    "in": [
                        {
                            "source": "#main/find_tRNA_matches/hmmer_search_results",
                            "valueFrom": "${ return [ self ]; }",
                            "id": "#main/collate_unique_tRNA_hmmer_hits/hits"
                        }
                    ],
                    "out": [
                        "#main/collate_unique_tRNA_hmmer_hits/unique_hits"
                    ],
                    "id": "#main/collate_unique_tRNA_hmmer_hits"
                },
                {
                    "run": "#seqprep-merge.cwl",
                    "in": [
                        {
                            "source": "#main/overlap_reads/forward_unmerged_reads",
                            "id": "#main/combine_seqprep/forward_unmerged_reads"
                        },
                        {
                            "source": "#main/overlap_reads/merged_reads",
                            "id": "#main/combine_seqprep/merged_reads"
                        },
                        {
                            "source": "#main/overlap_reads/reverse_unmerged_reads",
                            "id": "#main/combine_seqprep/reverse_unmerged_reads"
                        }
                    ],
                    "out": [
                        "#main/combine_seqprep/merged_with_unmerged_reads"
                    ],
                    "id": "#main/combine_seqprep"
                },
                {
                    "run": "#fastq_to_fasta.cwl",
                    "in": [
                        {
                            "source": "#main/trim_quality_control/reads1_trimmed",
                            "id": "#main/convert_trimmed-reads_to_fasta/fastq"
                        }
                    ],
                    "out": [
                        "#main/convert_trimmed-reads_to_fasta/fasta"
                    ],
                    "id": "#main/convert_trimmed-reads_to_fasta"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/find_16S_matches/indexed_sequences"
                        },
                        {
                            "source": "#main/16S_model",
                            "id": "#main/find_16S_matches/model"
                        }
                    ],
                    "out": [
                        "#main/find_16S_matches/matching_sequences",
                        "#main/find_16S_matches/hmmer_search_results"
                    ],
                    "id": "#main/find_16S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/find_23S_matches/indexed_sequences"
                        },
                        {
                            "source": "#main/23S_model",
                            "id": "#main/find_23S_matches/model"
                        }
                    ],
                    "out": [
                        "#main/find_23S_matches/matching_sequences",
                        "#main/find_23S_matches/hmmer_search_results"
                    ],
                    "id": "#main/find_23S_matches"
                },
                {
                    "run": "#rRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/find_5S_matches/indexed_sequences"
                        },
                        {
                            "source": "#main/5S_model",
                            "id": "#main/find_5S_matches/model"
                        }
                    ],
                    "out": [
                        "#main/find_5S_matches/matching_sequences",
                        "#main/find_5S_matches/hmmer_search_results"
                    ],
                    "id": "#main/find_5S_matches"
                },
                {
                    "run": "#tRNA_selection.cwl",
                    "in": [
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/find_tRNA_matches/indexed_sequences"
                        },
                        {
                            "source": "#main/tRNA_model",
                            "id": "#main/find_tRNA_matches/model"
                        }
                    ],
                    "out": [
                        "#main/find_tRNA_matches/matching_sequences",
                        "#main/find_tRNA_matches/hmmer_search_results"
                    ],
                    "id": "#main/find_tRNA_matches"
                },
                {
                    "run": "#FragGeneScan1_20.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/fraggenescan/completeSeq"
                        },
                        {
                            "source": "#main/fraggenescan_model",
                            "id": "#main/fraggenescan/model"
                        },
                        {
                            "source": "#main/fraggenescan_prob_backward",
                            "id": "#main/fraggenescan/prob_backward"
                        },
                        {
                            "source": "#main/fraggenescan_prob_forward",
                            "id": "#main/fraggenescan/prob_forward"
                        },
                        {
                            "source": "#main/fraggenescan_prob_noncoding",
                            "id": "#main/fraggenescan/prob_noncoding"
                        },
                        {
                            "source": "#main/fraggenescan_prob_start",
                            "id": "#main/fraggenescan/prob_start"
                        },
                        {
                            "source": "#main/fraggenescan_prob_start1",
                            "id": "#main/fraggenescan/prob_start1"
                        },
                        {
                            "source": "#main/fraggenescan_prob_stop",
                            "id": "#main/fraggenescan/prob_stop"
                        },
                        {
                            "source": "#main/fraggenescan_prob_stop1",
                            "id": "#main/fraggenescan/prob_stop1"
                        },
                        {
                            "source": "#main/fraggenescan_pwm_dist",
                            "id": "#main/fraggenescan/pwm_dist"
                        },
                        {
                            "source": "#main/mask_rRNA_and_tRNA/masked_sequences",
                            "id": "#main/fraggenescan/sequence"
                        }
                    ],
                    "out": [
                        "#main/fraggenescan/predictedCDS"
                    ],
                    "id": "#main/fraggenescan"
                },
                {
                    "run": "#esl-sfetch-index.cwl",
                    "in": [
                        {
                            "source": "#main/convert_trimmed-reads_to_fasta/fasta",
                            "id": "#main/index_reads/sequences"
                        }
                    ],
                    "out": [
                        "#main/index_reads/sequences_with_index"
                    ],
                    "id": "#main/index_reads"
                },
                {
                    "run": "#InterProScan5.21-60.cwl",
                    "in": [
                        {
                            "default": [
                                "Pfam",
                                "TIGRFAM",
                                "PRINTS",
                                "ProSitePatterns",
                                "Gene3d"
                            ],
                            "id": "#main/interproscan/applications"
                        },
                        {
                            "source": "#main/fraggenescan/predictedCDS",
                            "id": "#main/interproscan/proteinFile"
                        }
                    ],
                    "out": [
                        "#main/interproscan/i5Annotations"
                    ],
                    "id": "#main/interproscan"
                },
                {
                    "run": "#mask_RNA.cwl",
                    "in": [
                        {
                            "source": "#main/find_16S_matches/matching_sequences",
                            "id": "#main/mask_rRNA_and_tRNA/16s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#main/find_23S_matches/matching_sequences",
                            "id": "#main/mask_rRNA_and_tRNA/23s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#main/find_5S_matches/matching_sequences",
                            "id": "#main/mask_rRNA_and_tRNA/5s_rRNA_hmmer_matches"
                        },
                        {
                            "source": "#main/index_reads/sequences_with_index",
                            "id": "#main/mask_rRNA_and_tRNA/sequences"
                        },
                        {
                            "source": "#main/find_tRNA_matches/matching_sequences",
                            "id": "#main/mask_rRNA_and_tRNA/tRNA_matches"
                        },
                        {
                            "source": "#main/collate_unique_rRNA_hmmer_hits/unique_hits",
                            "id": "#main/mask_rRNA_and_tRNA/unique_rRNA_hits"
                        },
                        {
                            "source": "#main/collate_unique_tRNA_hmmer_hits/unique_hits",
                            "id": "#main/mask_rRNA_and_tRNA/unique_tRNA_hits"
                        }
                    ],
                    "out": [
                        "#main/mask_rRNA_and_tRNA/masked_sequences"
                    ],
                    "id": "#main/mask_rRNA_and_tRNA"
                },
                {
                    "run": "#seqprep.cwl",
                    "in": [
                        {
                            "source": "#main/forward_reads",
                            "id": "#main/overlap_reads/forward_reads"
                        },
                        {
                            "source": "#main/reverse_reads",
                            "id": "#main/overlap_reads/reverse_reads"
                        }
                    ],
                    "out": [
                        "#main/overlap_reads/merged_reads",
                        "#main/overlap_reads/forward_unmerged_reads",
                        "#main/overlap_reads/reverse_unmerged_reads"
                    ],
                    "id": "#main/overlap_reads"
                },
                {
                    "run": "#trimmomatic.cwl",
                    "in": [
                        {
                            "default": "SE",
                            "id": "#main/trim_quality_control/end_mode"
                        },
                        {
                            "default": 3,
                            "id": "#main/trim_quality_control/leading"
                        },
                        {
                            "default": "33",
                            "id": "#main/trim_quality_control/phred"
                        },
                        {
                            "source": "#main/combine_seqprep/merged_with_unmerged_reads",
                            "id": "#main/trim_quality_control/reads1"
                        },
                        {
                            "default": {
                                "windowSize": 4,
                                "requiredQuality": 15
                            },
                            "id": "#main/trim_quality_control/slidingwindow"
                        },
                        {
                            "default": 3,
                            "id": "#main/trim_quality_control/trailing"
                        }
                    ],
                    "out": [
                        "#main/trim_quality_control/reads1_trimmed"
                    ],
                    "id": "#main/trim_quality_control"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/"
    }
}
